Documentation
¶
Overview ¶
Copyright © 2026 hossiy21
Index ¶
- Variables
- func CheckForUpdates(verbose bool)
- func Execute()
- func RunFix(envFile, exampleFile string, dryRun bool) (int, error)
- func ShannonEntropy(data string) float64
- type AuditReport
- type DiffResult
- type EnvVar
- type ScanOutput
- type ScanResult
- type ScanSummary
- type ValidateOutput
- type ValidateSummary
- type ValidationResult
Constants ¶
This section is empty.
Variables ¶
var CurrentVersion = "v0.1.0"
Functions ¶
func CheckForUpdates ¶
func CheckForUpdates(verbose bool)
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func ShannonEntropy ¶
Types ¶
type AuditReport ¶
type AuditReport struct {
Score int
ScanCritical int
ScanHigh int
ScanMedium int
Missing int
Placeholder int
Empty int
Passed int
DiffCount int
}
func RunAudit ¶
func RunAudit(envFile, exampleFile string) (AuditReport, error)
type DiffResult ¶
type EnvVar ¶
type EnvVar struct {
Key string
Value string
Comment string
Required bool
Category string
Tags map[string]string
LineNum int
Ignored bool
}
func ParseEnvWithMetadata ¶
type ScanOutput ¶
type ScanOutput struct {
File string `json:"file"`
Results []ScanResult `json:"results"`
Summary ScanSummary `json:"summary"`
}
type ScanResult ¶
type ScanResult struct {
Line int `json:"line"`
Key string `json:"key"`
Value string `json:"value"`
Reason string `json:"reason"`
Risk string `json:"risk"`
}
func RunScan ¶
func RunScan(filename string) ([]ScanResult, error)
type ScanSummary ¶
type ValidateOutput ¶
type ValidateOutput struct {
EnvFile string `json:"env_file"`
ExampleFile string `json:"example_file"`
Results []ValidationResult `json:"results"`
Summary ValidateSummary `json:"summary"`
}
type ValidateSummary ¶
type ValidationResult ¶
type ValidationResult struct {
Key string `json:"key"`
Status string `json:"status"`
Message string `json:"message"`
}
func RunValidate ¶
Click to show internal directories.
Click to hide internal directories.